==> haskell-type-hint-0.1-30-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-type-hint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 type-hint
version:              0.1
visibility:           public
id:                   type-hint-0.1-KKnJgUdWloncAAGzhk3ln
key:                  type-hint-0.1-KKnJgUdWloncAAGzhk3ln
license:              BSD-3-Clause
copyright:            2014 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer:           Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author:               Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability:            experimental
homepage:             https://github.com/mvv/type-hint
synopsis:             Guide type inference with proxy values
description:
    This package provides '\''Proxy'\'' values for various types from the @base@
    library and functions to use these values as hints for type inference.

category:             Phantom Types
abi:                  9324d0f6f18b16f0969acfd12467b826
exposed:              True
exposed-modules:      Type.Hint
import-dirs:          /usr/lib/ghc-9.2.8/site-local/type-hint-0.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/type-hint-0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-type-hint
hs-libraries:         HStype-hint-0.1-KKnJgUdWloncAAGzhk3ln
depends:              base-4.16.4.0
haddock-interfaces:   /usr/share/doc/haskell-type-hint/html/type-hint.haddock
haddock-html:         /usr/share/doc/haskell-type-hint/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-type-hint-0.1-31-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-type-hint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 type-hint
version:              0.1
visibility:           public
id:                   type-hint-0.1-BLZkEIaqz7B91MRxOq10xP
key:                  type-hint-0.1-BLZkEIaqz7B91MRxOq10xP
license:              BSD-3-Clause
copyright:            2014 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer:           Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author:               Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability:            experimental
homepage:             https://github.com/mvv/type-hint
synopsis:             Guide type inference with proxy values
description:
    This package provides '\''Proxy'\'' values for various types from the @base@
    library and functions to use these values as hints for type inference.

category:             Phantom Types
abi:                  bd51fe39371ad7474f2b83f16baa7068
exposed:              True
exposed-modules:      Type.Hint
import-dirs:          /usr/lib/ghc-9.4.8/site-local/type-hint-0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/type-hint-0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/type-hint-0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-type-hint
hs-libraries:         HStype-hint-0.1-BLZkEIaqz7B91MRxOq10xP
depends:              base-4.17.2.1
haddock-interfaces:   /usr/share/doc/haskell-type-hint/html/type-hint.haddock
haddock-html:         /usr/share/doc/haskell-type-hint/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
